Functions and Conditionals Mixed-Up Code Questions
---------------------------------------------------

.. selectquestion:: funct_conditional_mixedupcode_1_sq
   :fromid: funct_conditional_mixedupcode_1, funct_conditional_mixedupcode_1_ac
   :toggle: 


.. selectquestion:: funct_conditional_mixedupcode_2_sq
   :fromid: funct_conditional_mixedupcode_2, funct_conditional_mixedupcode_2_ac
   :toggle: 


.. selectquestion:: funct_conditional_mixedupcode_3_sq
   :fromid: funct_conditional_mixedupcode_3, funct_conditional_mixedupcode_3_ac
   :toggle: 


.. selectquestion:: funct_conditional_mixedupcode_4_sq
   :fromid: funct_conditional_mixedupcode_4, funct_conditional_mixedupcode_4_ac
   :toggle: 


.. selectquestion:: funct_conditional_mixedupcode_5_sq
   :fromid: funct_conditional_mixedupcode_5, funct_conditional_mixedupcode_5_ac
   :toggle: 

